<?php
/**
 * Action pour affecter un type de plugin à un plugin.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Action pour affecter un type de plugin à un plugin.
 *
 * Cette action est réservée aux utilisateurs pouvant affecter un type de plugin.
 * L'argument attendu est `id_mot_actuel:prefixe:id_mot:typologie`.
 *
 * @uses plugin_desaffecter_type_plugin()
 * @uses plugin_affecter_type_plugin()
 *
 * @param null|string $arguments Arguments de l'action ou null si l'action est appelée par une URL
 *
 * @return void
 */
function action_affecter_plugin_dist(?string $arguments = null) : void {
	// Récupération des arguments de façon sécurisée.
	if (null === $arguments) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arguments = $securiser_action();
	}

	$arguments = explode(':', $arguments);
	[$id_mot_affecte, $id_plugin, $prefixe, $id_mot, $typologie] = $arguments;

	// Verification des autorisations
	include_spip('inc/autoriser');
	if (!autoriser('affecter', 'type_plugin', $id_plugin)) {
		include_spip('inc/minipres');
		echo minipres();
		exit();
	}

	include_spip('inc/svptype_plugin');
	// Si on a passé un id non nul dans $id_mot_affecte c'est qu'on veut changer ce mot par un nouveau.
	// Il faut donc supprimer cette affectation au préalable.
	if ($id_mot_affecte) {
		plugin_desaffecter_type_plugin($prefixe, $id_mot_affecte);
	}

	// Maintenant on peut ajouter la nouvelle affectation
	plugin_affecter_type_plugin($prefixe, $id_mot, $typologie);
}
